@@ -13,8 +13,12 @@ dis(pickle, out=None, memo=None, indentlevel=4)
 import codecs
 import re
 import sys
+from pickle import decode_long
+from struct import unpack as _unpack
+
 from zodbpickle import pickle_3 as pickle
 
+
 __all__ = ['dis', 'genops', 'optimize']
 
 bytes_types = pickle.bytes_types
@@ -170,7 +174,8 @@ TAKEN_FROM_ARGUMENT1  = -2   # num bytes is 1-byte unsigned int
 TAKEN_FROM_ARGUMENT4  = -3   # num bytes is 4-byte signed little-endian int
 TAKEN_FROM_ARGUMENT4U = -4   # num bytes is 4-byte unsigned little-endian int
 
-class ArgumentDescriptor(object):
+
+class ArgumentDescriptor:
     __slots__ = (
         # name of descriptor record, also a module global name; a string
         'name',
@@ -205,7 +210,6 @@ class ArgumentDescriptor(object):
         assert isinstance(doc, str)
         self.doc = doc
 
-from struct import unpack as _unpack
 
 def read_uint1(f):
     r"""
@@ -219,11 +223,12 @@ def read_uint1(f):
         return data[0]
     raise ValueError("not enough data in stream to read uint1")
 
+
 uint1 = ArgumentDescriptor(
-            name='uint1',
-            n=1,
-            reader=read_uint1,
-            doc="One-byte unsigned integer.")
+    name='uint1',
+    n=1,
+    reader=read_uint1,
+    doc="One-byte unsigned integer.")
 
 
 def read_uint2(f):
@@ -240,11 +245,12 @@ def read_uint2(f):
         return _unpack("<H", data)[0]
     raise ValueError("not enough data in stream to read uint2")
 
+
 uint2 = ArgumentDescriptor(
-            name='uint2',
-            n=2,
-            reader=read_uint2,
-            doc="Two-byte unsigned integer, little-endian.")
+    name='uint2',
+    n=2,
+    reader=read_uint2,
+    doc="Two-byte unsigned integer, little-endian.")
 
 
 def read_int4(f):
@@ -261,11 +267,12 @@ def read_int4(f):
         return _unpack("<i", data)[0]
     raise ValueError("not enough data in stream to read int4")
 
+
 int4 = ArgumentDescriptor(
-           name='int4',
-           n=4,
-           reader=read_int4,
-           doc="Four-byte signed integer, little-endian, 2's complement.")
+    name='int4',
+    n=4,
+    reader=read_int4,
+    doc="Four-byte signed integer, little-endian, 2's complement.")
 
 
 def read_uint4(f):
@@ -282,11 +289,12 @@ def read_uint4(f):
         return _unpack("<I", data)[0]
     raise ValueError("not enough data in stream to read uint4")
 
+
 uint4 = ArgumentDescriptor(
-            name='uint4',
-            n=4,
-            reader=read_uint4,
-            doc="Four-byte unsigned integer, little-endian.")
+    name='uint4',
+    n=4,
+    reader=read_uint4,
+    doc="Four-byte unsigned integer, little-endian.")
 
 
 def read_stringnl(f, decode=True, stripquotes=True):
@@ -336,30 +344,34 @@ def read_stringnl(f, decode=True, stripquotes=True):
         data = codecs.escape_decode(data)[0].decode("ascii")
     return data
 
+
 stringnl = ArgumentDescriptor(
-               name='stringnl',
-               n=UP_TO_NEWLINE,
-               reader=read_stringnl,
-               doc="""A newline-terminated string.
+    name='stringnl',
+    n=UP_TO_NEWLINE,
+    reader=read_stringnl,
+    doc="""A newline-terminated string.
 
                    This is a repr-style string, with embedded escapes, and
                    bracketing quotes.
                    """)
 
+
 def read_stringnl_noescape(f):
     return read_stringnl(f, stripquotes=False)
 
+
 stringnl_noescape = ArgumentDescriptor(
-                        name='stringnl_noescape',
-                        n=UP_TO_NEWLINE,
-                        reader=read_stringnl_noescape,
-                        doc="""A newline-terminated string.
+    name='stringnl_noescape',
+    n=UP_TO_NEWLINE,
+    reader=read_stringnl_noescape,
+    doc="""A newline-terminated string.
 
                         This is a str-style string, without embedded escapes,
                         or bracketing quotes.  It should consist solely of
                         printable ASCII characters.
                         """)
 
+
 def read_stringnl_noescape_pair(f):
     r"""
     >>> import io
@@ -367,13 +379,14 @@ def read_stringnl_noescape_pair(f):
     'Queue Empty'
     """
 
-    return "%s %s" % (read_stringnl_noescape(f), read_stringnl_noescape(f))
+    return "{} {}".format(read_stringnl_noescape(f), read_stringnl_noescape(f))
+
 
 stringnl_noescape_pair = ArgumentDescriptor(
-                             name='stringnl_noescape_pair',
-                             n=UP_TO_NEWLINE,
-                             reader=read_stringnl_noescape_pair,
-                             doc="""A pair of newline-terminated strings.
+    name='stringnl_noescape_pair',
+    n=UP_TO_NEWLINE,
+    reader=read_stringnl_noescape_pair,
+    doc="""A pair of newline-terminated strings.
 
                              These are str-style strings, without embedded
                              escapes, or bracketing quotes.  They should
@@ -382,6 +395,7 @@ stringnl_noescape_pair = ArgumentDescriptor(
                              a single blank separating the two strings.
                              """)
 
+
 def read_string4(f):
     r"""
     >>> import io
@@ -404,11 +418,12 @@ def read_string4(f):
     raise ValueError("expected %d bytes in a string4, but only %d remain" %
                      (n, len(data)))
 
+
 string4 = ArgumentDescriptor(
-              name="string4",
-              n=TAKEN_FROM_ARGUMENT4,
-              reader=read_string4,
-              doc="""A counted string.
+    name="string4",
+    n=TAKEN_FROM_ARGUMENT4,
+    reader=read_string4,
+    doc="""A counted string.
 
               The first argument is a 4-byte little-endian signed int giving
               the number of bytes in the string, and the second argument is
@@ -433,11 +448,12 @@ def read_string1(f):
     raise ValueError("expected %d bytes in a string1, but only %d remain" %
                      (n, len(data)))
 
+
 string1 = ArgumentDescriptor(
-              name="string1",
-              n=TAKEN_FROM_ARGUMENT1,
-              reader=read_string1,
-              doc="""A counted string.
+    name="string1",
+    n=TAKEN_FROM_ARGUMENT1,
+    reader=read_string1,
+    doc="""A counted string.
 
               The first argument is a 1-byte unsigned int giving the number
               of bytes in the string, and the second argument is that many
@@ -462,11 +478,12 @@ def read_bytes1(f):
     raise ValueError("expected %d bytes in a bytes1, but only %d remain" %
                      (n, len(data)))
 
+
 bytes1 = ArgumentDescriptor(
-              name="bytes1",
-              n=TAKEN_FROM_ARGUMENT1,
-              reader=read_bytes1,
-              doc="""A counted bytes string.
+    name="bytes1",
+    n=TAKEN_FROM_ARGUMENT1,
+    reader=read_bytes1,
+    doc="""A counted bytes string.
 
               The first argument is a 1-byte unsigned int giving the number
               of bytes, and the second argument is that many bytes.
@@ -495,11 +512,12 @@ def read_bytes4(f):
     raise ValueError("expected %d bytes in a bytes4, but only %d remain" %
                      (n, len(data)))
 
+
 bytes4 = ArgumentDescriptor(
-              name="bytes4",
-              n=TAKEN_FROM_ARGUMENT4U,
-              reader=read_bytes4,
-              doc="""A counted bytes string.
+    name="bytes4",
+    n=TAKEN_FROM_ARGUMENT4U,
+    reader=read_bytes4,
+    doc="""A counted bytes string.
 
               The first argument is a 4-byte little-endian unsigned int giving
               the number of bytes, and the second argument is that many bytes.
@@ -520,17 +538,19 @@ def read_unicodestringnl(f):
     data = data[:-1]    # lose the newline
     return str(data, 'raw-unicode-escape')
 
+
 unicodestringnl = ArgumentDescriptor(
-                      name='unicodestringnl',
-                      n=UP_TO_NEWLINE,
-                      reader=read_unicodestringnl,
-                      doc="""A newline-terminated Unicode string.
+    name='unicodestringnl',
+    n=UP_TO_NEWLINE,
+    reader=read_unicodestringnl,
+    doc="""A newline-terminated Unicode string.
 
                       This is raw-unicode-escape encoded, so consists of
                       printable ASCII characters, and may contain embedded
                       escape sequences.
                       """)
 
+
 def read_unicodestring4(f):
     r"""
     >>> import io
@@ -558,11 +578,12 @@ def read_unicodestring4(f):
     raise ValueError("expected %d bytes in a unicodestring4, but only %d "
                      "remain" % (n, len(data)))
 
+
 unicodestring4 = ArgumentDescriptor(
-                    name="unicodestring4",
-                    n=TAKEN_FROM_ARGUMENT4U,
-                    reader=read_unicodestring4,
-                    doc="""A counted Unicode string.
+    name="unicodestring4",
+    n=TAKEN_FROM_ARGUMENT4U,
+    reader=read_unicodestring4,
+    doc="""A counted Unicode string.
 
                     The first argument is a 4-byte little-endian signed int
                     giving the number of bytes in the string, and the second
@@ -597,6 +618,7 @@ def read_decimalnl_short(f):
 
     return int(s)
 
+
 def read_decimalnl_long(f):
     r"""
     >>> import io
@@ -615,10 +637,10 @@ def read_decimalnl_long(f):
 
 
 decimalnl_short = ArgumentDescriptor(
-                      name='decimalnl_short',
-                      n=UP_TO_NEWLINE,
-                      reader=read_decimalnl_short,
-                      doc="""A newline-terminated decimal integer literal.
+    name='decimalnl_short',
+    n=UP_TO_NEWLINE,
+    reader=read_decimalnl_short,
+    doc="""A newline-terminated decimal integer literal.
 
                           This never has a trailing 'L', and the integer fit
                           in a short Python int on the box where the pickle
@@ -628,10 +650,10 @@ decimalnl_short = ArgumentDescriptor(
                           """)
 
 decimalnl_long = ArgumentDescriptor(
-                     name='decimalnl_long',
-                     n=UP_TO_NEWLINE,
-                     reader=read_decimalnl_long,
-                     doc="""A newline-terminated decimal integer literal.
+    name='decimalnl_long',
+    n=UP_TO_NEWLINE,
+    reader=read_decimalnl_long,
+    doc="""A newline-terminated decimal integer literal.
 
                          This has a trailing 'L', and can represent integers
                          of any size.
@@ -647,11 +669,12 @@ def read_floatnl(f):
     s = read_stringnl(f, decode=False, stripquotes=False)
     return float(s)
 
+
 floatnl = ArgumentDescriptor(
-              name='floatnl',
-              n=UP_TO_NEWLINE,
-              reader=read_floatnl,
-              doc="""A newline-terminated decimal floating literal.
+    name='floatnl',
+    n=UP_TO_NEWLINE,
+    reader=read_floatnl,
+    doc="""A newline-terminated decimal floating literal.
 
               In general this requires 17 significant digits for roundtrip
               identity, and pickling then unpickling infinities, NaNs, and
@@ -660,6 +683,7 @@ floatnl = ArgumentDescriptor(
               for infinities or NaNs).
               """)
 
+
 def read_float8(f):
     r"""
     >>> import io, struct
@@ -677,10 +701,10 @@ def read_float8(f):
 
 
 float8 = ArgumentDescriptor(
-             name='float8',
-             n=8,
-             reader=read_float8,
-             doc="""An 8-byte binary representation of a float, big-endian.
+    name='float8',
+    n=8,
+    reader=read_float8,
+    doc="""An 8-byte binary representation of a float, big-endian.
 
              The format is unique to Python, and shared with the struct
              module (format string '>d') "in theory" (the struct and pickle
@@ -696,7 +720,6 @@ float8 = ArgumentDescriptor(
 
 # Protocol 2 formats
 
-from pickle import decode_long
 
 def read_long1(f):
     r"""
@@ -719,6 +742,7 @@ def read_long1(f):
         raise ValueError("not enough data in stream to read long1")
     return decode_long(data)
 
+
 long1 = ArgumentDescriptor(
     name="long1",
     n=TAKEN_FROM_ARGUMENT1,
@@ -730,6 +754,7 @@ long1 = ArgumentDescriptor(
     If the size is 0, that's taken as a shortcut for the long 0L.
     """)
 
+
 def read_long4(f):
     r"""
     >>> import io
@@ -753,6 +778,7 @@ def read_long4(f):
         raise ValueError("not enough data in stream to read long4")
     return decode_long(data)
 
+
 long4 = ArgumentDescriptor(
     name="long4",
     n=TAKEN_FROM_ARGUMENT4,
@@ -773,7 +799,7 @@ long4 = ArgumentDescriptor(
 # descriptors we need names to describe the various types of objects that can
 # appear on the stack.
 
-class StackObject(object):
+class StackObject:
     __slots__ = (
         # name of descriptor record, for info only
         'name',
@@ -804,75 +830,75 @@ class StackObject(object):
 
 
 pyint = StackObject(
-            name='int',
-            obtype=int,
-            doc="A short (as opposed to long) Python integer object.")
+    name='int',
+    obtype=int,
+    doc="A short (as opposed to long) Python integer object.")
 
 pylong = StackObject(
-             name='long',
-             obtype=int,
-             doc="A long (as opposed to short) Python integer object.")
+    name='long',
+    obtype=int,
+    doc="A long (as opposed to short) Python integer object.")
 
 pyinteger_or_bool = StackObject(
-                        name='int_or_bool',
-                        obtype=(int, bool),
-                        doc="A Python integer object (short or long), or "
-                            "a Python bool.")
+    name='int_or_bool',
+    obtype=(int, bool),
+    doc="A Python integer object (short or long), or "
+    "a Python bool.")
 
 pybool = StackObject(
-             name='bool',
-             obtype=(bool,),
-             doc="A Python bool object.")
+    name='bool',
+    obtype=(bool,),
+    doc="A Python bool object.")
 
 pyfloat = StackObject(
-              name='float',
-              obtype=float,
-              doc="A Python float object.")
+    name='float',
+    obtype=float,
+    doc="A Python float object.")
 
 pystring = StackObject(
-               name='string',
-               obtype=bytes,
-               doc="A Python (8-bit) string object.")
+    name='string',
+    obtype=bytes,
+    doc="A Python (8-bit) string object.")
 
 pybytes = StackObject(
-               name='bytes',
-               obtype=bytes,
-               doc="A Python bytes object.")
+    name='bytes',
+    obtype=bytes,
+    doc="A Python bytes object.")
 
 pyunicode = StackObject(
-                name='str',
-                obtype=str,
-                doc="A Python (Unicode) string object.")
+    name='str',
+    obtype=str,
+    doc="A Python (Unicode) string object.")
 
 pynone = StackObject(
-             name="None",
-             obtype=type(None),
-             doc="The Python None object.")
+    name="None",
+    obtype=type(None),
+    doc="The Python None object.")
 
 pytuple = StackObject(
-              name="tuple",
-              obtype=tuple,
-              doc="A Python tuple object.")
+    name="tuple",
+    obtype=tuple,
+    doc="A Python tuple object.")
 
 pylist = StackObject(
-             name="list",
-             obtype=list,
-             doc="A Python list object.")
+    name="list",
+    obtype=list,
+    doc="A Python list object.")
 
 pydict = StackObject(
-             name="dict",
-             obtype=dict,
-             doc="A Python dict object.")
+    name="dict",
+    obtype=dict,
+    doc="A Python dict object.")
 
 anyobject = StackObject(
-                name='any',
-                obtype=object,
-                doc="Any kind of object whatsoever.")
+    name='any',
+    obtype=object,
+    doc="Any kind of object whatsoever.")
 
 markobject = StackObject(
-                 name="mark",
-                 obtype=StackObject,
-                 doc="""'The mark' is a unique object.
+    name="mark",
+    obtype=StackObject,
+    doc="""'The mark' is a unique object.
 
                  Opcodes that operate on a variable number of objects
                  generally don't embed the count of objects in the opcode,
@@ -884,9 +910,9 @@ markobject = StackObject(
                  """)
 
 stackslice = StackObject(
-                 name="stackslice",
-                 obtype=StackObject,
-                 doc="""An object representing a contiguous slice of the stack.
+    name="stackslice",
+    obtype=StackObject,
+    doc="""An object representing a contiguous slice of the stack.
 
                  This is used in conjuction with markobject, to represent all
                  of the stack following the topmost markobject.  For example,
@@ -904,7 +930,8 @@ stackslice = StackObject(
 ##############################################################################
 # Descriptors for pickle opcodes.
 
-class OpcodeInfo(object):
+
+class OpcodeInfo:
 
     __slots__ = (
         # symbolic name of opcode; a string
@@ -963,6 +990,7 @@ class OpcodeInfo(object):
         assert isinstance(doc, str)
         self.doc = doc
 
+
 I = OpcodeInfo
 opcodes = [
 
@@ -1129,9 +1157,9 @@ opcodes = [
       proto=3,
       doc="""Push a Python bytes object.
 
-      There are two arguments:  the first is a 4-byte little-endian unsigned int
-      giving the number of bytes, and the second is that many bytes, which are
-      taken literally as the bytes content.
+      There are two arguments:  the first is a 4-byte little-endian unsigned
+      int giving the number of bytes, and the second is that many bytes, which
+      are taken literally as the bytes content.
       """),
 
     I(name='SHORT_BINBYTES',
@@ -1203,8 +1231,8 @@ opcodes = [
       proto=1,
       doc="""Push a Python Unicode string object.
 
-      There are two arguments:  the first is a 4-byte little-endian unsigned int
-      giving the number of bytes in the string.  The second is that many
+      There are two arguments:  the first is a 4-byte little-endian unsigned
+      int giving the number of bytes in the string.  The second is that many
       bytes, and is the UTF-8 encoding of the Unicode string.
       """),
 
@@ -1864,24 +1892,27 @@ for d in opcodes:
     code2op[d.code] = d
 del d
 
+
 def assure_pickle_consistency(verbose=False):
 
     copy = code2op.copy()
     for name in pickle.__all__:
         if not re.match("[A-Z][A-Z0-9_]+$", name):
             if verbose:
-                print("skipping %r: it doesn't look like an opcode name" % name)
+                print(
+                    "skipping %r: it doesn't look like an opcode name" %
+                    name)
             continue
         picklecode = getattr(pickle, name)
         if not isinstance(picklecode, bytes) or len(picklecode) != 1:
             if verbose:
-                print(("skipping %r: value %r doesn't look like a pickle "
-                       "code" % (name, picklecode)))
+                print("skipping %r: value %r doesn't look like a pickle "
+                      "code" % (name, picklecode))
             continue
         picklecode = picklecode.decode("latin-1")
         if picklecode in copy:
             if verbose:
-                print("checking name %r w/ code %r for consistency" % (
+                print("checking name {!r} w/ code {!r} for consistency".format(
                       name, picklecode))
             d = copy[picklecode]
             if d.name != name:
@@ -1899,15 +1930,17 @@ def assure_pickle_consistency(verbose=False):
     if copy:
         msg = ["we appear to have pickle opcodes that pickle.py doesn't have:"]
         for code, d in copy.items():
-            msg.append("    name %r with code %r" % (d.name, code))
+            msg.append("    name {!r} with code {!r}".format(d.name, code))
         raise ValueError("\n".join(msg))
 
+
 assure_pickle_consistency()
 del assure_pickle_consistency
 
 ##############################################################################
 # A pickle opcode generator.
 
+
 def genops(pickle):
     """Generate all the opcodes in a pickle.
 
@@ -1939,7 +1972,8 @@ def genops(pickle):
     if hasattr(pickle, "tell"):
         getpos = pickle.tell
     else:
-        getpos = lambda: None
+        def getpos():
+            return None
 
     while True:
         pos = getpos()
@@ -1949,7 +1983,7 @@ def genops(pickle):
             if code == b"":
                 raise ValueError("pickle exhausted before seeing STOP")
             else:
-                raise ValueError("at position %s, opcode %r unknown" % (
+                raise ValueError("at position {}, opcode {!r} unknown".format(
                                  pos is None and "<unknown>" or pos,
                                  code))
         if opcode.arg is None:
@@ -1964,11 +1998,13 @@ def genops(pickle):
 ##############################################################################
 # A pickle optimizer.
 
+
 def optimize(p):
     'Optimize a pickle string by removing unused PUT opcodes'
     gets = set()            # set of args used by a GET opcode
     puts = []               # (arg, startpos, stoppos) for the PUT opcodes
     prevpos = None          # set to pos if previous opcode was a PUT
+    prevarg = None
     for opcode, arg, pos in genops(p):
         if prevpos is not None:
             puts.append((prevarg, prevpos, pos))
@@ -1991,6 +2027,7 @@ def optimize(p):
 ##############################################################################
 # A symbolic pickle disassembler.
 
+
 def dis(pickle, out=None, memo=None, indentlevel=4, annotate=0):
     """Produce a symbolic disassembly of a pickle.
 
@@ -2142,10 +2179,13 @@ def dis(pickle, out=None, memo=None, indentlevel=4, annotate=0):
         raise ValueError("stack not empty after STOP: %r" % stack)
 
 # For use in the doctest, simply as an example of a class to pickle.
+
+
 class _Example:
     def __init__(self, value):
         self.value = value
 
+
 _dis_test_3_6 = r"""
 >>> import pickle
 >>> x = [1, 2, (3, 4), {b'abc': "def"}]
@@ -2399,7 +2439,7 @@ Try protocol 3 with annotations:
    14: .    STOP         Stop the unpickling machine.
 highest protocol among opcodes = 2
 
-"""
+"""  # noqa: E501 line too long
 
 _dis_test_3_7 = r"""
 >>> import pickle
@@ -2654,7 +2694,7 @@ Try protocol 3 with annotations:
    14: .    STOP         Stop the unpickling machine.
 highest protocol among opcodes = 2
 
-"""
+"""  # noqa: E501 line too long
 
 # There are some slight differences since 3.7 - for now copied
 # the whole test - this can be removed if py3.6 support is dropped.
@@ -2695,14 +2735,17 @@ highest protocol among opcodes = 2
 
 __test__ = {'disassembler_test': _dis_test,
             'disassembler_memo_test': _memo_test,
-           }
+            }
+
 
 def _test():
     import doctest
     return doctest.testmod()
 
+
 if __name__ == "__main__":
-    import sys, argparse
+    import argparse
+    import sys
     parser = argparse.ArgumentParser(
         description='disassemble one or more pickle files')
     parser.add_argument(
@@ -2718,7 +2761,7 @@ if __name__ == "__main__":
         '-l', '--indentlevel', default=4, type=int,
         help='the number of blanks by which to indent a new MARK level')
     parser.add_argument(
-        '-a', '--annotate',  action='store_true',
+        '-a', '--annotate', action='store_true',
         help='annotate each line with a short opcode description')
     parser.add_argument(
         '-p', '--preamble', default="==> {name} <==",
