@@ -1,26 +1,35 @@
+import copyreg
 import io
 import os
-import unittest
 import sys
-import copyreg
-import weakref
 import tempfile
+import unittest
+import weakref
 from http.cookies import SimpleCookie
+from test.support import _2G
+from test.support import _4G
+from test.support import TestFailed
+from test.support import bigmemtest
+from test.support import run_with_locale
+
+import __main__
+
 from zodbpickle import pickle_3 as pickle
 from zodbpickle import pickletools_3 as pickletools
+from zodbpickle.pickle_3 import bytes_types
+
+from . import _is_pypy
 
-from test.support import (
-    TestFailed, run_with_locale,
-    _2G, _4G, bigmemtest,
-    )
 
 try:
     from test.support import no_tracing
 except ImportError:
     from functools import wraps
+
     def no_tracing(func):
         if not hasattr(sys, 'gettrace'):
             return func
+
         @wraps(func)
         def wrapper(*args, **kwargs):
             original_trace = sys.gettrace()
@@ -31,11 +40,8 @@ except ImportError:
                 sys.settrace(original_trace)
         return wrapper
 
-_PY343 = sys.version_info[:3] >= (3, 4, 3)
 _PY311b1 = sys.hexversion >= 0x30b00b1  # 3.11.0b1
 
-from zodbpickle.pickle_3 import bytes_types
-from . import _is_pypy
 
 # Tests that try a number of pickle protocols should have a
 #     for proto in protocols:
@@ -48,6 +54,8 @@ fd, TESTFN = tempfile.mkstemp('.pickletester_3')
 os.close(fd)
 
 # Return True if opcode code appears in the pickle, else False.
+
+
 def opcode_in_pickle(code, pickle):
     for op, dummy, dummy in pickletools.genops(pickle):
         if op.code == code.decode("latin-1"):
@@ -55,6 +63,8 @@ def opcode_in_pickle(code, pickle):
     return False
 
 # Return the number of times opcode code appears in pickle.
+
+
 def count_opcode(code, pickle):
     n = 0
     for op, dummy, dummy in pickletools.genops(pickle):
@@ -108,19 +118,22 @@ class ExtensionSaver:
         if pair is not None:
             copyreg.add_extension(pair[0], pair[1], code)
 
+
 class C:
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
 
+
 class D(C):
     def __init__(self, arg):
         pass
 
+
 class E(C):
     def __getinitargs__(self):
         return ()
 
-import __main__
+
 __main__.C = C
 C.__module__ = "__main__"
 __main__.D = D
@@ -128,10 +141,12 @@ D.__module__ = "__main__"
 __main__.E = E
 E.__module__ = "__main__"
 
+
 class myint(int):
     def __init__(self, x):
         self.str = str(x)
 
+
 class initarg(C):
 
     def __init__(self, a, b):
@@ -141,20 +156,24 @@ class initarg(C):
     def __getinitargs__(self):
         return self.a, self.b
 
+
 class metaclass(type):
     pass
 
-class use_metaclass(object, metaclass=metaclass):
+
+class use_metaclass(metaclass=metaclass):
     pass
 
+
 class pickling_metaclass(type):
     def __eq__(self, other):
-        return (type(self) == type(other) and
+        return (isinstance(self, type(other)) and
                 self.reduce_args == other.reduce_args)
 
     def __reduce__(self):
         return (create_dynamic_class, self.reduce_args)
 
+
 def create_dynamic_class(name, bases):
     result = pickling_metaclass(name, bases, dict())
     result.reduce_args = (name, bases)
@@ -163,6 +182,7 @@ def create_dynamic_class(name, bases):
 # DATA0 .. DATA2 are the pickles we expect under the various protocols, for
 # the object returned by create_data().
 
+
 DATA0 = (
     b'(lp0\nL0L\naL1L\naF2.0\nac'
     b'builtins\ncomplex\n'
@@ -433,26 +453,28 @@ DATA5 = (b'\x80\x02cCookie\nSimpleCookie\nq\x00)\x81q\x01U\x03key'
 DATA6 = b'\x80\x02c__builtin__\nset\nq\x00]q\x01K\x03a\x85q\x02Rq\x03.'
 DATA6_PYPY = b'\x80\x02c__builtin__\nset\nq\x00K\x03\x85q\x01\x85q\x02Rq\x03.'
 
+
 def create_data():
     c = C()
     c.foo = 1
     c.bar = 2
-    x = [0, 1, 2.0, 3.0+0j]
+    x = [0, 1, 2.0, 3.0 + 0j]
     # Append some integer test cases at cPickle.c's internal size
     # cutoffs.
     uint1max = 0xff
     uint2max = 0xffff
     int4max = 0x7fffffff
     x.extend([1, -1,
-              uint1max, -uint1max, -uint1max-1,
-              uint2max, -uint2max, -uint2max-1,
-               int4max,  -int4max,  -int4max-1])
+              uint1max, -uint1max, -uint1max - 1,
+              uint2max, -uint2max, -uint2max - 1,
+              int4max, -int4max, -int4max - 1])
     y = ('abc', 'abc', c, c)
     x.append(y)
     x.append(y)
     x.append(5)
     return x
 
+
 class AbstractPickleTests(unittest.TestCase):
     # Subclass must define self.dumps, self.loads.
 
@@ -572,10 +594,10 @@ class AbstractPickleTests(unittest.TestCase):
             self.assertEqual(expected, got)
 
     def test_recursive_list(self):
-        l = []
-        l.append(l)
+        l_ = []
+        l_.append(l_)
         for proto in protocols:
-            s = self.dumps(l, proto)
+            s = self.dumps(l_, proto)
             x = self.loads(s)
             self.assertEqual(len(x), 1)
             self.assertTrue(x is x[0])
@@ -609,13 +631,13 @@ class AbstractPickleTests(unittest.TestCase):
             self.assertIs(x.attr, x)
 
     def test_recursive_multi(self):
-        l = []
-        d = {1:l}
+        l_ = []
+        d = {1: l_}
         i = C()
         i.attr = d
-        l.append(i)
+        l_.append(i)
         for proto in protocols:
-            s = self.dumps(l, proto)
+            s = self.dumps(l_, proto)
             x = self.loads(s)
             self.assertEqual(len(x), 1)
             self.assertEqual(dir(x[0]), dir(i))
@@ -628,12 +650,12 @@ class AbstractPickleTests(unittest.TestCase):
 
     def test_insecure_strings(self):
         # XXX Some of these tests are temporarily disabled
-        insecure = [b"abc", b"2 + 2", # not quoted
-                    ## b"'abc' + 'def'", # not a single quoted string
-                    b"'abc", # quote is not closed
-                    b"'abc\"", # open quote and close quote don't match
-                    b"'abc'   ?", # junk after close quote
-                    b"'\\'", # trailing backslash
+        insecure = [b"abc", b"2 + 2",  # not quoted
+                    # b"'abc' + 'def'", # not a single quoted string
+                    b"'abc",  # quote is not closed
+                    b"'abc\"",  # open quote and close quote don't match
+                    b"'abc'   ?",  # junk after close quote
+                    b"'\\'",  # trailing backslash
                     # Variations on issue #17710
                     b"'",
                     b'"',
@@ -643,8 +665,8 @@ class AbstractPickleTests(unittest.TestCase):
                     b"'    ",
                     b'"    ',
                     # some tests of the quoting rules
-                    ## b"'abc\"\''",
-                    ## b"'\\\\a\'\'\'\\\'\\\\\''",
+                    # b"'abc\"\''",
+                    # b"'\\\\a\'\'\'\\\'\\\\\''",
                     ]
         for b in insecure:
             buf = b"S" + b + b"\012p0\012."
@@ -670,7 +692,7 @@ class AbstractPickleTests(unittest.TestCase):
 
     def test_bytes(self):
         for proto in protocols:
-            for s in b'', b'xyz', b'xyz'*100:
+            for s in b'', b'xyz', b'xyz' * 100:
                 p = self.dumps(s, proto)
                 self.assertEqual(self.loads(p), s)
             for s in [bytes([i]) for i in range(256)]:
@@ -704,9 +726,9 @@ class AbstractPickleTests(unittest.TestCase):
     def test_long(self):
         for proto in protocols:
             # 256 bytes is where LONG4 begins.
-            for nbits in 1, 8, 8*254, 8*255, 8*256, 8*257:
+            for nbits in 1, 8, 8 * 254, 8 * 255, 8 * 256, 8 * 257:
                 nbase = 1 << nbits
-                for npos in nbase-1, nbase, nbase+1:
+                for npos in nbase - 1, nbase, nbase + 1:
                     for n in npos, -npos:
                         pickle = self.dumps(n, proto)
                         got = self.loads(pickle)
@@ -762,8 +784,8 @@ class AbstractPickleTests(unittest.TestCase):
             self.assertEqual(a, b)
 
     def test_structseq(self):
-        import time
         import os
+        import time
 
         t = time.localtime()
         for proto in protocols:
@@ -810,7 +832,7 @@ class AbstractPickleTests(unittest.TestCase):
             self.loads(badpickle)
         except ValueError as detail:
             self.assertTrue(str(detail).startswith(
-                                            "unsupported pickle protocol"))
+                "unsupported pickle protocol"))
         else:
             self.fail("expected bad protocol number to raise ValueError")
 
@@ -823,7 +845,7 @@ class AbstractPickleTests(unittest.TestCase):
             self.assertEqual(opcode_in_pickle(pickle.LONG1, s), proto >= 2)
 
     def test_long4(self):
-        x = 12345678910111213141516178920 << (256*8)
+        x = 12345678910111213141516178920 << (256 * 8)
         for proto in protocols:
             s = self.dumps(x, proto)
             y = self.loads(s)
@@ -855,7 +877,7 @@ class AbstractPickleTests(unittest.TestCase):
                            (3, 2): pickle.TUPLE2,
                            (3, 3): pickle.TUPLE3,
                            (3, 4): pickle.TUPLE,
-                          }
+                           }
         a = ()
         b = (1,)
         c = (1, 2)
@@ -885,7 +907,7 @@ class AbstractPickleTests(unittest.TestCase):
                            (1, False): pickle.INT,
                            (2, False): pickle.NEWFALSE,
                            (3, False): pickle.NEWFALSE,
-                          }
+                           }
         for proto in protocols:
             for x in None, False, True:
                 s = self.dumps(x, proto)
@@ -1127,11 +1149,12 @@ class AbstractPickleTests(unittest.TestCase):
     def test_reduce_bad_iterator(self):
         # Issue4176: crash when 4th and 5th items of __reduce__()
         # are not iterators
-        class C(object):
+        class C:
             def __reduce__(self):
                 # 4th item is not an iterator
                 return list, (), None, [], None
-        class D(object):
+
+        class D:
             def __reduce__(self):
                 # 5th item is not an iterator
                 return dict, (), None, None, []
@@ -1151,7 +1174,7 @@ class AbstractPickleTests(unittest.TestCase):
         # Test that internal data structures correctly deal with lots of
         # puts/gets.
         keys = ("aaa" + str(i) for i in range(100))
-        large_dict = dict((k, [4, 5, 6]) for k in keys)
+        large_dict = {k: [4, 5, 6] for k in keys}
         obj = [dict(large_dict), dict(large_dict), dict(large_dict)]
 
         for proto in protocols:
@@ -1164,7 +1187,7 @@ class AbstractPickleTests(unittest.TestCase):
     @unittest.skipIf(_is_pypy,
                      'PyPy does not guarantee the identity of strings. '
                      'See the discussion on '
-                     'http://pypy.readthedocs.org/en/latest/cpython_differences.html#object-identity-of-primitive-values-is-and-id')
+                     'http://pypy.readthedocs.org/en/latest/cpython_differences.html#object-identity-of-primitive-values-is-and-id')  # noqa: E501 line too long
     def test_attribute_name_interning(self):
         # Test that attribute names of pickled objects are interned when
         # unpickling.
@@ -1182,21 +1205,14 @@ class AbstractPickleTests(unittest.TestCase):
     def test_unpickle_from_2x(self):
         # Unpickle non-trivial data from Python 2.x.
         loaded = self.loads(DATA3)
-        self.assertEqual(loaded, set([1, 2]))
+        self.assertEqual(loaded, {1, 2})
         loaded = self.loads(DATA4)
         self.assertEqual(type(loaded), type(range(0)))
         self.assertEqual(list(loaded), list(range(5)))
         loaded = self.loads(DATA5)
         self.assertEqual(type(loaded), SimpleCookie)
         self.assertEqual(list(loaded.keys()), ["key"])
-        if _PY343:
-            # The SimpleCookie object changed the way it gets
-            # constructed in Python 3.4.3; the old behaviour was
-            # broken.
-            # See http://bugs.python.org/issue22775
-            self.assertEqual(loaded["key"].value, "value")
-        else:
-            self.assertEqual(loaded["key"].value, "Set-Cookie: key=value")
+        self.assertEqual(loaded["key"].value, "value")
 
     def test_pickle_to_2x(self):
         # Pickle non-trivial data with protocol 2, expecting that it yields
@@ -1206,7 +1222,7 @@ class AbstractPickleTests(unittest.TestCase):
         dumped = self.dumps(range(5), 2)
         self.assertEqual(dumped, DATA4)
 
-        dumped = self.dumps(set([3]), 2)
+        dumped = self.dumps({3}, 2)
         if not _is_pypy:
             # The integer in the set is pickled differently under PyPy
             # due to the differing identity semantics (?)
@@ -1323,50 +1339,67 @@ class AbstractBytestrTests(unittest.TestCase):
         """ Test str from protocol=0
             python 2: pickle.dumps('bytestring \x00\xa0', protocol=0) """
         self.unpickleEqual(
-                b"S'bytestring \\x00\\xa0'\np0\n.",
-                b'bytestring \x00\xa0')
+            b"S'bytestring \\x00\\xa0'\np0\n.",
+            b'bytestring \x00\xa0')
 
     def test_load_str_protocol_1(self):
         """ Test str from protocol=1
         python 2: pickle.dumps('bytestring \x00\xa0', protocol=1) """
         self.unpickleEqual(
-                b'U\rbytestring \x00\xa0q\x00.',
-                b'bytestring \x00\xa0')
+            b'U\rbytestring \x00\xa0q\x00.',
+            b'bytestring \x00\xa0')
 
     def test_load_str_protocol_2(self):
         """ Test str from protocol=2
         python 2: pickle.dumps('bytestring \x00\xa0', protocol=2) """
         self.unpickleEqual(
-                b'\x80\x02U\rbytestring \x00\xa0q\x00.',
-                b'bytestring \x00\xa0')
+            b'\x80\x02U\rbytestring \x00\xa0q\x00.',
+            b'bytestring \x00\xa0')
 
     def test_load_unicode_protocol_0(self):
         """ Test unicode with protocol=0
-        python 2: pickle.dumps(u"\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440", protocol=0) """
+        python 2: pickle.dumps(
+            u"\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440",
+            protocol=0)
+        """
         self.unpickleEqual(
-                b'V\\u041a\\u043e\\u043c\\u043f\\u044c\\u044e\\u0442\\u0435\\u0440\np0\n.',
-                '\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440')
+            b'V\\u041a\\u043e\\u043c\\u043f\\u044c\\u044e\\u0442\\u0435'
+            b'\\u0440\np0\n.',
+            '\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440')
 
     def test_load_unicode_protocol_1(self):
         """ Test unicode with protocol=1
-        python 2: pickle.dumps(u"\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440", protocol=1) """
+        python 2: pickle.dumps(
+            u"\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440",
+            protocol=1)
+        """
         self.unpickleEqual(
-                b'X\x12\x00\x00\x00\xd0\x9a\xd0\xbe\xd0\xbc\xd0\xbf\xd1\x8c\xd1\x8e\xd1\x82\xd0\xb5\xd1\x80q\x00.',
-                '\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440')
+            b'X\x12\x00\x00\x00\xd0\x9a\xd0\xbe\xd0\xbc\xd0\xbf\xd1\x8c\xd1'
+            b'\x8e\xd1\x82\xd0\xb5\xd1\x80q\x00.',
+            '\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440')
 
     def test_load_unicode_protocol_2(self):
         """ Test unicode with protocol=1
-        python 2: pickle.dumps(u"\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440", protocol=2) """
+        python 2: pickle.dumps(
+            u"\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440",
+            protocol=2)
+        """
         self.unpickleEqual(
-                b'\x80\x02X\x12\x00\x00\x00\xd0\x9a\xd0\xbe\xd0\xbc\xd0\xbf\xd1\x8c\xd1\x8e\xd1\x82\xd0\xb5\xd1\x80q\x00.',
-                '\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440')
+            b'\x80\x02X\x12\x00\x00\x00\xd0\x9a\xd0\xbe\xd0\xbc\xd0\xbf\xd1'
+            b'\x8c\xd1\x8e\xd1\x82\xd0\xb5\xd1\x80q\x00.',
+            '\u041a\u043e\u043c\u043f\u044c\u044e\u0442\u0435\u0440')
 
     def test_load_long_str_protocol_1(self):
         """ Test long str with protocol=1
         python 2: pickle.dumps('x'*300, protocol=1) """
         self.unpickleEqual(
-                b'T,\x01\x00\x00xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxq\x00.',
-                b'x'*300)
+            b'T,\x01\x00\x00xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'
+            b'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'
+            b'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'
+            b'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'
+            b'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'
+            b'q\x00.', b'x' * 300)
+
 
 class AbstractBytesFallbackTests(unittest.TestCase):
     def unpickleEqual(self, data, unpickled):
@@ -1378,8 +1411,8 @@ class AbstractBytesFallbackTests(unittest.TestCase):
 
         Python 2: pickle.dumps({'x': 'ascii', 'y': '\xff'}) """
         self.unpickleEqual(
-                b"(dp0\nS'y'\np1\nS'\\xff'\np2\nsS'x'\np3\nS'ascii'\np4\ns.",
-                {'x': 'ascii', 'y': b'\xff'})
+            b"(dp0\nS'y'\np1\nS'\\xff'\np2\nsS'x'\np3\nS'ascii'\np4\ns.",
+            {'x': 'ascii', 'y': b'\xff'})
 
 
 class BigmemPickleTests(unittest.TestCase):
@@ -1465,65 +1498,85 @@ class BigmemPickleTests(unittest.TestCase):
 
 # Test classes for reduce_ex
 
-class REX_one(object):
+class REX_one:
     """No __reduce_ex__ here, but inheriting it from object"""
     _reduce_called = 0
+
     def __reduce__(self):
         self._reduce_called = 1
         return REX_one, ()
 
-class REX_two(object):
+
+class REX_two:
     """No __reduce__ here, but inheriting it from object"""
     _proto = None
+
     def __reduce_ex__(self, proto):
         self._proto = proto
         return REX_two, ()
 
-class REX_three(object):
+
+class REX_three:
     _proto = None
+
     def __reduce_ex__(self, proto):
         self._proto = proto
         return REX_two, ()
+
     def __reduce__(self):
         raise TestFailed("This __reduce__ shouldn't be called")
 
-class REX_four(object):
+
+class REX_four:
     """Calling base class method should succeed"""
     _proto = None
+
     def __reduce_ex__(self, proto):
         self._proto = proto
         return object.__reduce_ex__(self, proto)
 
-class REX_five(object):
+
+class REX_five:
     """This one used to fail with infinite recursion"""
     _reduce_called = 0
+
     def __reduce__(self):
         self._reduce_called = 1
         return object.__reduce__(self)
 
-class REX_six(object):
-    """This class is used to check the 4th argument (list iterator) of the reduce
-    protocol.
+
+class REX_six:
+    """This class is used to check the 4th argument (list iterator) of the
+    reduce protocol.
     """
+
     def __init__(self, items=None):
         self.items = items if items is not None else []
+
     def __eq__(self, other):
-        return type(self) is type(other) and self.items == self.items
+        return isinstance(self, type(other)) and self.items == self.items
+
     def append(self, item):
         self.items.append(item)
+
     def __reduce__(self):
         return type(self), (), None, iter(self.items), None
 
-class REX_seven(object):
-    """This class is used to check the 5th argument (dict iterator) of the reduce
-    protocol.
+
+class REX_seven:
+    """This class is used to check the 5th argument (dict iterator) of the
+    reduce protocol.
     """
+
     def __init__(self, table=None):
         self.table = table if table is not None else {}
+
     def __eq__(self, other):
-        return type(self) is type(other) and self.table == self.table
+        return isinstance(self, type(other)) and self.table == self.table
+
     def __setitem__(self, key, value):
         self.table[key] = value
+
     def __reduce__(self):
         return type(self), (), None, None, iter(self.table.items())
 
@@ -1533,27 +1586,35 @@ class REX_seven(object):
 class MyInt(int):
     sample = 1
 
+
 class MyFloat(float):
     sample = 1.0
 
+
 class MyComplex(complex):
     sample = 1.0 + 0.0j
 
+
 class MyStr(str):
     sample = "hello"
 
+
 class MyUnicode(str):
     sample = "hello \u1234"
 
+
 class MyTuple(tuple):
     sample = (1, 2, 3)
 
+
 class MyList(list):
     sample = [1, 2, 3]
 
+
 class MyDict(dict):
     sample = {"a": 1, "b": 2}
 
+
 myclasses = [MyInt, MyFloat,
              MyComplex,
              MyStr, MyUnicode,
@@ -1563,11 +1624,13 @@ myclasses = [MyInt, MyFloat,
 class SlotList(MyList):
     __slots__ = ["foo"]
 
-class SimpleNewObj(object):
+
+class SimpleNewObj:
     def __init__(self, a, b, c):
         # raise an error, to make sure this isn't called
         raise TypeError("SimpleNewObj.__init__() didn't expect to get called")
 
+
 class BadGetattr:
     def __getattr__(self, key):
         self.foo
@@ -1616,8 +1679,9 @@ class AbstractPickleModuleTests(unittest.TestCase):
         pickle.Pickler(f, protocol=-1)
 
     def test_bad_init(self):
-        # Test issue3664 (pickle can segfault from a badly initialized Pickler).
-        # Override initialization without calling __init__() of the superclass.
+        # Test issue3664 (pickle can segfault from a badly initialized
+        # Pickler). Override initialization without calling __init__() of the
+        # superclass.
         class BadPickler(pickle.Pickler):
             def __init__(self): pass
 
@@ -1852,38 +1916,39 @@ class AbstractPicklerUnpicklerObjectTests(unittest.TestCase):
         after['ggg'] = f.tell()
         f.seek(0)
         unpickler = self.unpickler_class(f)
-        unpickler.noload() # read past _NOLOAD_OBJECT
+        unpickler.noload()  # read past _NOLOAD_OBJECT
         self.assertEqual(f.tell(), after['_NOLOAD_OBJECT'])
 
-        noload = unpickler.noload() # read past aaa
+        noload = unpickler.noload()  # read past aaa
         self.assertEqual(noload, None)
         self.assertEqual(f.tell(), after['aaa'])
 
-        unpickler.noload() # read past bbb
+        unpickler.noload()  # read past bbb
         self.assertEqual(f.tell(), after['bbb'])
 
-        noload = unpickler.noload() # read past ccc
+        noload = unpickler.noload()  # read past ccc
         self.assertEqual(noload, ccc)
         self.assertEqual(f.tell(), after['ccc'])
 
-        noload = unpickler.noload() # read past ddd
+        noload = unpickler.noload()  # read past ddd
         self.assertEqual(noload, ddd)
         self.assertEqual(f.tell(), after['ddd'])
 
-        noload = unpickler.noload() # read past eee
+        noload = unpickler.noload()  # read past eee
         self.assertEqual(noload, eee)
         self.assertEqual(f.tell(), after['eee'])
 
-        noload = unpickler.noload() # read past fff
+        noload = unpickler.noload()  # read past fff
         self.assertEqual(noload, fff)
         self.assertEqual(f.tell(), after['fff'])
 
-        noload = unpickler.noload() # read past ggg
+        noload = unpickler.noload()  # read past ggg
         self.assertEqual(noload, ggg)
         self.assertEqual(f.tell(), after['ggg'])
 
     def test_functional_noload_dict_subclass(self):
-        """noload() doesn't break or produce any output given a dict subclass"""
+        """noload() doesn't break or produce any output given a dict subclass
+        """
         # See http://bugs.python.org/issue1101399
         o = MyDict()
         o['x'] = 1
@@ -1895,9 +1960,9 @@ class AbstractPicklerUnpicklerObjectTests(unittest.TestCase):
         noload = unpickler.noload()
         self.assertEqual(noload, None)
 
-
     def test_functional_noload_list_subclass(self):
-        """noload() doesn't break or produce any output given a list subclass"""
+        """noload() doesn't break or produce any output given a list subclass
+        """
         # See http://bugs.python.org/issue1101399
         o = MyList()
         o.append(1)
@@ -1922,7 +1987,6 @@ class AbstractPicklerUnpicklerObjectTests(unittest.TestCase):
         noload = unpickler.noload()
         self.assertEqual(noload, o)
 
-
     def test_functional_noload_list(self):
         """noload() implements the Python 2.6 behaviour and fills in lists"""
         # See http://bugs.python.org/issue1101399
@@ -1941,13 +2005,16 @@ class AbstractPicklerUnpicklerObjectTests(unittest.TestCase):
 
 REDUCE_A = 'reduce_A'
 
-class AAA(object):
+
+class AAA:
     def __reduce__(self):
         return str, (REDUCE_A,)
 
-class BBB(object):
+
+class BBB:
     pass
 
+
 class AbstractDispatchTableTests(unittest.TestCase):
 
     def test_default_dispatch_table(self):
@@ -2003,6 +2070,7 @@ class AbstractDispatchTableTests(unittest.TestCase):
 
         # modify pickling of complex
         REDUCE_1 = 'reduce_1'
+
         def reduce_1(obj):
             return str, (REDUCE_1,)
         dispatch_table[complex] = reduce_1
@@ -2026,6 +2094,7 @@ class AbstractDispatchTableTests(unittest.TestCase):
 
         # revert pickling of BBB and modify pickling of AAA
         REDUCE_2 = 'reduce_2'
+
         def reduce_2(obj):
             return str, (REDUCE_2,)
         dispatch_table[AAA] = reduce_2
@@ -2042,14 +2111,14 @@ if __name__ == "__main__":
     x = create_data()
     for i in range(3):
         p = pickle.dumps(x, i)
-        print("DATA{0} = (".format(i))
+        print(f"DATA{i} = (")
         for j in range(0, len(p), 20):
-            b = bytes(p[j:j+20])
-            print("    {0!r}".format(b))
+            b = bytes(p[j:j + 20])
+            print(f"    {b!r}")
         print(")")
         print()
-        print("# Disassembly of DATA{0}".format(i))
-        print("DATA{0}_DIS = \"\"\"\\".format(i))
+        print(f"# Disassembly of DATA{i}")
+        print(f"DATA{i}_DIS = \"\"\"\\")
         dis(p)
         print("\"\"\"")
         print()
